@@ -24,7 +24,7 @@ except ImportError:
 TEXT_ENDPOINT = "https://api.houndify.com/v1/text"
 VOICE_ENDPOINT = "https://api.houndify.com/v1/audio"
 TRANSCRIPTION_ENDPOINT = "https://api.houndify.com/v1/transcription"
-VERSION = "2.0.8"
+VERSION = "2.0.9"
 
 
 class HoundifySDKError(Exception):
@@ -197,9 +197,14 @@ class HoundListener(object):
       than 2 complete sentences. The first sentence can migrate to final
       """
       pass
-    def onDetailedFinalPartialTranscript(self, transcript):
+    def onPartialTranscriptTokens(self, transcript):
       """
-      onDetailedFinalPartialTranscript is fired once the server has identified more
+      onPartialTranscriptTokens is fired when the server has a partial transcript.
+      """
+      pass
+    def onFinalPartialTranscriptTokens(self, transcript):
+      """
+      onFinalPartialTranscriptTokens is fired once the server has identified more
       than 2 complete sentences and contains more detailed information about each
       FinalPartialTranscript received.
       """
@@ -447,7 +452,11 @@ class StreamingHoundClient(_BaseHoundClient):
               except:
                 pass
               try:
-                listener.onDetailedFinalPartialTranscript(parsedMsg["DetailedFinalPartialTranscript"])
+                listener.onPartialTranscriptTokens(parsedMsg["PartialTranscriptTokens"])
+              except:
+                pass
+              try:
+                listener.onFinalPartialTranscriptTokens(parsedMsg["FinalPartialTranscriptTokens"])
               except:
                 pass
               listener.onPartialTranscript(parsedMsg["PartialTranscript"])
